SkyMarshal
==========

Simple cross-language message definitions with marshalling/unmarshalling code generation.

An easy-to-maintain pure-Python implementation of `lcm-gen` of the
[LCM Project](https://github.com/lcm-proj/lcm), with wire format compatibility.  Skymarshal adds additional features, including more supported languages and additional features for existing
languages.

Built by [Skydio](https://skydio.com), used by [SymForce](https://symforce.org).
